@@ -1,6 +1,8 @@
 import re
-from util import *
+import click
+import configparser
 
+from aos.util import *
 
 # Cfg classed used for handling the config backend
 class Cfg(object):
@@ -97,3 +99,42 @@ class Global(object):
     @staticmethod
     def list_cfg(*args, **kwargs):
         return Cfg(Global.path).list(*args, **kwargs)
+
+class Config():
+    def __init__(self, conf_file):
+        self.conf_file = conf_file
+        self.conf = configparser.ConfigParser()
+        self.conf.read(self.conf_file)
+
+    def list(self, section=None, name=None):
+        if section and name:
+            if not section in self.conf.sections():
+                error("No section %s found in %s" % (section, self.conf_file))
+                return
+            if not name in self.conf.options(section):
+                error("No option %s found in %s" % (name, self.conf_file))
+                return
+
+            click.echo("%s.%s=%s" % (section, name, self.conf.get(section, name)))
+
+        elif section:
+            for name in self.conf.options(section):
+                click.echo("%s.%s=%s" % (section, name, self.conf.get(section, name)))
+        else:
+            for section in self.conf.sections():
+                for name in self.conf.options(section):
+                    click.echo("%s.%s=%s" % (section, name, self.conf.get(section, name)))
+
+    def set(self, section, name, value):
+        if not section in self.conf.sections():
+            self.conf.add_section(section)
+
+        self.conf.set(section, name, value)
+
+    def clean(self, section):
+        if section in self.conf.sections():
+            self.conf.remove_section(section)
+
+    def write(self):
+        with open (self.conf_file, "w") as f:
+            self.conf.write(f)
