@@ -481,7 +481,8 @@ def get_board_dir(board, source_root, board_dirs=None):
         if os.path.isdir(tmp):
             board_dir = tmp
             break
-
+    if not board_dir and board == "board_comp_make":
+        board_dir = board
     return board_dir
 
 def update_config_in():
